from .find import Finder
# from .scholar import ScholarSearch
from .acm import ACMSearch
from .ieee import IEEESearch
from .search import Search
from .sciencedirect import ScienceDirectSearch
from .springer import SpringerLinkSearch